@@ -157,5 +157,8 @@ struct Metrics {
 
     // shadow dimensions
     static constexpr int Shadow_Overlap = 2;
+
+    // frame intensities (called bias in KColorUtilities::Mix)
+    static constexpr qreal Bias_Default = 0.25;
 };
 }
